<?php
# This file is part of the Savane project
# <http://gna.org/projects/savane/>
#
# $Id: group_type.php,v 1.26 2004/09/22 08:11:50 yeupou Exp $
#
#  Copyright (C) 2002-2004 Mathieu Roy <yeupou--at--gnu.org>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.


require "../include/pre.php";
require  $GLOBALS['sys_urlroot']."/include/vars.php";
require_directory("project");

session_require(array('group'=>'1','admin_flags'=>'A'));

# group public choice
if ($delete)
{
  $result = db_query("DELETE FROM group_type WHERE type_id='$form_type_id'");

  if (!$result)
    { fb(_("Unable to delete group type"),0); }
  else
    { fb(_("group type deleted")); }

}

if ($update) {

  $sql = "UPDATE group_type SET " . "name='$form_name',"
     . "description='$form_description',"
     . "base_host='$form_base_host',"
     . "can_use_homepage='$form_can_use_homepage',"
     . "dir_type_cvs='$form_dir_type_cvs',"
     . "dir_type_download='$form_dir_type_download',"
     . "dir_type_homepage='$form_dir_type_homepage',"
     . "dir_cvs='$form_dir_cvs',"
     . "dir_homepage='$form_dir_homepage',"
     . "url_homepage='$form_url_homepage',"
     . "url_cvs_viewcvs_homepage='$form_url_cvs_viewcvs_homepage',"
     . "can_use_cvs='$form_can_use_cvs',"
     . "can_use_forum='$form_can_use_forum',"
     . "url_cvs_viewcvs='$form_url_cvs_viewcvs',"
     . "can_use_license='$form_can_use_license',"
     . "license_array='$form_license_array',"
     . "can_use_devel_status='$form_can_use_devel_status',"
     . "devel_status_array='$form_devel_status_array',"
     . "can_use_download='$form_can_use_download',"
     . "dir_download='$form_dir_download',"
     . "url_download='$form_url_download',"
     . "can_use_mailing_list='$form_can_use_mailing_list',"
     . "mailing_list_host='$form_mailing_list_host',"
     . "url_mailing_list_listinfo='$form_url_mailing_list_listinfo',"
     . "url_mailing_list_subscribe='$form_url_mailing_list_subscribe',"
     . "url_mailing_list_unsubscribe='$form_url_mailing_list_unsubscribe',"
     . "url_mailing_list_archives='$form_url_mailing_list_archives',"
     . "url_mailing_list_archives_private='$form_url_mailing_list_archives_private',"
     . "url_mailing_list_admin='$form_url_mailing_list_admin',"
     . "mailing_list_address='$form_mailing_list_address',"
     . "mailing_list_format='$form_mailing_list_format',"
     . "can_use_forum='$form_can_use_forum',"
     . "can_use_patch='$form_can_use_patch',"
     . "can_use_task='$form_can_use_task',"
     . "can_use_news='$form_can_use_news',"
     . "can_use_bug='$form_can_use_bug',"
     . "admin_email_adress='$form_admin_email_adress' WHERE "
     . "type_id='$form_type_id'";

  $result = db_query($sql);

  if (!$result)
    { fb(sprintf(_("Unable to update group type general settings: %s"), db_error()),1); }
  else
    { fb(_("group type general settings updated")); }

  $result = db_query("UPDATE group_type SET "
		     . "is_menu_configurable_homepage='$form_is_menu_configurable_homepage',"
		     . "is_menu_configurable_extralink_documentation='$form_is_menu_configurable_extralink_documentation',"
		     . "is_menu_configurable_download='$form_is_menu_configurable_download',"
		     . "is_menu_configurable_support='$form_is_menu_configurable_support',"
		     . "is_menu_configurable_forum='$form_is_menu_configurable_forum',"
		     . "is_menu_configurable_mail='$form_is_menu_configurable_mail',"
		     . "is_menu_configurable_cvs='$form_is_menu_configurable_cvs',"
		     . "is_menu_configurable_cvs_viewcvs='$form_is_menu_configurable_cvs_viewcvs',"
		     . "is_menu_configurable_cvs_viewcvs_homepage='$form_is_menu_configurable_cvs_viewcvs_homepage',"
		     . "is_menu_configurable_bugs='$form_is_menu_configurable_bugs',"
		     . "is_menu_configurable_task='$form_is_menu_configurable_task',"
		     . "is_menu_configurable_patch='$form_is_menu_configurable_patch',"
		     . "is_configurable_download_dir='$form_is_menu_configurable_download_dir'"
		     . " WHERE "
		     . "type_id='$form_type_id'");

  if (!$result)
    { fb(sprintf(_("Unable to update group type menu settings: %s"), db_error()),0); }
  else
    { fb(_("group type menu settings updated")); }

  $bugs_flags="bugs_user_";
  $task_flags="task_user_";
  $patch_flags="patch_user_";
  $support_flags="support_user_";
  $news_flags="news_user_";

  $sql = 'UPDATE group_type SET '
     ."bugs_flags=".$$bugs_flags.","
     ."news_flags=".$$news_flags.","
     ."task_flags=".$$task_flags.", "
     ."patch_flags=".$$patch_flags.", "
     ."support_flags=".$$support_flags." "
     ."WHERE type_id='$form_type_id'";

  $result = db_query($sql);

  if (!$result)
    { fb(sprintf(_("Unable to update group type user permissions settings: %s"), db_error()),0); }
  else
    { fb(_("group type user permissions settings updated")); }

  $bugs_flags="bugs_restrict";
  $task_flags="task_restrict";
  $patch_flags="patch_restrict";
  $support_flags="support_restrict";
  $news_flags="news_restrict";

  $sql = 'UPDATE group_type SET '
     ."bugs_rflags=".$$bugs_flags.","
     ."news_rflags=".$$news_flags.","
     ."task_rflags=".$$task_flags.", "
     ."patch_rflags=".$$patch_flags.", "
     ."support_rflags=".$$support_flags." "
     ."WHERE type_id='$form_type_id'";

  $result = db_query($sql);

  if (!$result)
    { fb(sprintf(_("Unable to update group type posting restrictions settings: %s"), db_error()),0); }
  else
    { fb(_("group type posting restrictions settings updated")); }

}



if (!isset($type_id))
{
  site_admin_header(array('title'=>'Group Type Management','toptab'=>'admgrptype'));
  $result = db_query("SELECT type_id,name FROM group_type ORDER BY type_id");

  while ($usr = db_fetch_array($result))
    {
      print '<a href="'.$PHP_SELF.'?type_id='.$usr[type_id].'">Type #'.$usr[type_id].': '.$usr[name].'</a><br />';
      $last=$usr[type_id];
    }
  $type=$last+1;
  print '<a href="'.$PHP_SELF.'?type_id='.$type.'&amp;create=1">Create new group type</a>';

}
else
{

  if ($create == "1")
    {
      db_query("INSERT INTO group_type (type_id,name) VALUES ('$type_id','New type')");
      $update_button_text = _("Create");
    }
  else
    {
      $update_button_text = _("Update");
    }

  $result = db_query("SELECT * FROM group_type WHERE type_id='$type_id'");
  $row_grp = db_fetch_array($result);

  site_admin_header(array('title'=>"Edition/Creation of Group Type",'toptab'=>'admgrptype'));

  print '<H2>'.$row_grp['name'].' (#'.$row_grp['type_id'].')</H2>';


  print '<FORM action="'.$PHP_SELF.'" method="POST">
<INPUT type="hidden" name="form_type_id" value="'.$type_id.'">';

  # ####################################################################
  # GENERAL SETTINGS
  # ####################################################################

  $HTML->box1_top(_("General Default Settings for Groups of this Type"));

  $textfield_size='65';

  # ########### Help

  print '
<p>Basic Help: host means hostname (as savannah.gnu.org), dir means directory (as /usr/local/savannah), url means -well- url (as http:#savannah.gnu.org/blah ).

<p class="warn">Everytime a project\'s unix_group_name should appear, use the special string %PROJECT.

<p>Fields marked with [BACKEND SPECIFIC] are only useful is you use the savannah backend.

<p>Fill only the fields that have a specific setting, differing from the whole installation settings.

</td></tr><tr><td class="'.utils_get_alt_row_color($i).'">
<h3>General information:</h3>
Name:<br />
<input type="text" name="form_name" value="'.$row_grp['name'].'" size="'.$textfield_size.'">
<br />Base Host:<br />
<input type="text" name="form_base_host" value="'.$row_grp['base_host'].'" size="'.$textfield_size.'">
<br />Description (will be added on each project homepage):<br />
<textarea cols="'.$textfield_size.'" rows="6"wrap="virtual" name="form_description">'.$row_grp['description'].'</textarea>
<br />Admin Email Address:<br />
<input type="text" name="form_admin_email_adress" value="'.$row_grp['admin_email_adress'].'" size="'.$textfield_size.'">

';
  $i++;

  # ########### Homepage

  print '</td></tr><tr><td class="'.utils_get_alt_row_color($i).'">

<h3>Homepage:</h3>
<br /><INPUT TYPE="CHECKBOX" NAME="form_can_use_homepage" VALUE="1"'.( ($row_grp['can_use_homepage']==1) ? ' checked="checked"' : '' ).'> can use homepage.<br />';
  html_select_typedir_box("form_dir_type_homepage",
			  $row_grp['dir_type_homepage']);

  print '
<br />Homepage Dir (path on the filesystem) [BACKEND SPECIFIC]:<br />
<input type="text" name="form_dir_homepage" value="'.$row_grp['dir_homepage'].'" size="'.$textfield_size.'">';
  print '
<br /><br />Homepage URL:<br />
<input type="text" name="form_url_homepage" value="'.$row_grp['url_homepage'].'" size="'.$textfield_size.'">';

  print '
<br /><br />Homepage CVS view url (webcvs, viewcvs):<br />
<input type="text" name="form_url_cvs_viewcvs_homepage" value="'.$row_grp['url_cvs_viewcvs_homepage'].'" size="'.$textfield_size.'">

';
  $i++;

  # ########### Source code

  print '</td></tr><tr><td class="'.utils_get_alt_row_color($i).'">

<h3>Source Code (CVS):</h3>
<br /><INPUT TYPE="CHECKBOX" NAME="form_can_use_cvs" VALUE="1"'.( ($row_grp['can_use_cvs']==1) ? ' checked="checked"' : '' ).'> can use CVS<br />';

  html_select_typedir_box("form_dir_type_cvs",
			  $row_grp['dir_type_cvs']);

print '<br />CVS Dir (path on the filesystem) [BACKEND SPECIFIC]:<br />
<input type="text" name="form_dir_cvs" value="'.$row_grp['dir_cvs'].'" size="'.$textfield_size.'">
<br /><br />CVS view url (webcvs, viewcvs):<br />
<input type="text" name="form_url_cvs_viewcvs" value="'.$row_grp['url_cvs_viewcvs'].'" size="'.$textfield_size.'">
';
  $i++;

  # ########### License

  print '</td></tr><tr><td class="'.utils_get_alt_row_color($i).'">

<h3>License:</h3>
<br /><INPUT TYPE="CHECKBOX" NAME="form_can_use_license" VALUE="1"'.( ($row_grp['can_use_license']==1) ? ' checked="checked"' : '' ).'> can use license
<br /><br />License list (short name, update include/vars.php for name and url association):<br />
<TEXTAREA cols="'.$textfield_size.'" rows="6"wrap="virtual" name="form_license_array">'.$row_grp['license_array'].'</textarea>

';
  $i++;

  # ########### Devel status

  print '</td></tr><tr><td class="'.utils_get_alt_row_color($i).'">

<h3>Devel Status:</h3>
<br /><INPUT TYPE="CHECKBOX" NAME="form_can_use_devel_status" VALUE="1"'.( ($row_grp['can_use_license']==1) ? ' checked="checked"' : '' ).'> can use devel status
<br />
<br />Devel Status list:<br />
<TEXTAREA cols="'.$textfield_size.'" rows="6" wrap="virtual" name="form_devel_status_array">'.$row_grp['devel_status_array'].'</textarea>


';
  $i++;

  # ########### Download

  print '</td></tr><tr><td class="'.utils_get_alt_row_color($i).'">

<h3>Download Area:</h3>
<br /><INPUT TYPE="CHECKBOX" NAME="form_can_use_download" VALUE="1"'.( ($row_grp['can_use_download']==1) ? ' checked="checked"' : '' ).'>
can use download area.
<br />
';

  html_select_typedir_box("form_dir_type_download",
			  $row_grp['dir_type_download']);

  print '<br />Download Dir (path on the filesystem) [BACKEND SPECIFIC + filelist]:<br />
<input type="text" name="form_dir_download" value="'.$row_grp['dir_download'].'" size="'.$textfield_size.'">
<br /><br />Download Url:<br />
<input type="text" name="form_url_download" value="'.$row_grp['url_download'].'" size="'.$textfield_size.'">

';
  $i++;

  # ###########  Mailing List

  print '</td></tr><tr><td class="'.utils_get_alt_row_color($i).'">

<h3>Mailing list:</h3>

<font class="warn">Help: Everytime a mailing-list name should appear, use the special string %LIST. Note that if you do not want the Savannah software to interact with your mail host (for instance to truly create mailing list), do not fill the mail host information.</font>

<br />
<br /><INPUT TYPE="CHECKBOX" NAME="form_can_use_mailing_list" VALUE="1"'.( ($row_grp['can_use_mailing_list']==1) ? ' checked="checked"' : '' ).'>
Can use mailing-list.<br />
<br />Mailing List Host:<br />
<input type="text" name="form_mailing_list_host" value="'.$row_grp['mailing_list_host'].'" size="'.$textfield_size.'">

<br /><br />Mailing list address (would be %LIST@gnu.org for GNU projects at sv.gnu.org):<br />
<input type="text" name="form_mailing_list_address" value="'.$row_grp['mailing_list_address'].'" size="'.$textfield_size.'">

<br /><br />

<br />Mailing list name format:<br />
You can force projects to follow a specific policy for the name of the %LIST. Here you should use the special wildcard %NAME, which is the part the of the mailing list name that the project admin can define (would be %PROJECT-%NAME for non-GNU projects at sv.gnu.org).<br /><font class="warn">Do no add any @hostname here!</font><br />
<input type="text" name="form_mailing_list_format" value="'.$row_grp['mailing_list_format'].'" size="'.$textfield_size.'">

<br /><br />

<br />Listinfo Url:<br />
<input type="text" name="form_url_mailing_list_listinfo" value="'.$row_grp['url_mailing_list_listinfo'].'" size="'.$textfield_size.'">

<br /><br />Subscribe Url (for majordomo at CERN, it is majordomo_interface.php?func=subscribe&amp;list=%LIST&amp;mailserver=listbox.server@cern.ch):<br />
<input type="text" name="form_url_mailing_list_subscribe" value="'.$row_grp['url_mailing_list_subscribe'].'" size="'.$textfield_size.'">

<br /><br />Unsubscribe Url (for majordomo at CERN, it is majordomo_interface.php?func=subscribe&amp;list=%LIST&amp;mailserver=listbox.server@cern.ch):<br />
<input type="text" name="form_url_mailing_list_unsubscribe" value="'.$row_grp['url_mailing_list_unsubscribe'].'" size="'.$textfield_size.'">

<br /><br />Archives URl:<br />
<input type="text" name="form_url_mailing_list_archives" value="'.$row_grp['url_mailing_list_archives'].'" size="'.$textfield_size.'">

<br /><br />Private Archives URl:<br />
<input type="text" name="form_url_mailing_list_archives_private" value="'.$row_grp['url_mailing_list_archives_private'].'" size="'.$textfield_size.'">

<br /><br />Administrative Interface Url:<br />
<input type="text" name="form_url_mailing_list_admin" value="'.$row_grp['url_mailing_list_admin'].'" size="'.$textfield_size.'">

';
  $i++;

  # ########### Forum

  print '</td></tr><tr><td class="'.utils_get_alt_row_color($i).'">

<h3>Forum:</h3>
<br /><INPUT TYPE="CHECKBOX" NAME="form_can_use_forum" VALUE="1"'.( ($row_grp['can_use_forum']==1) ? ' checked="checked"' : '' ).'>
can use forum.
';
  $i++;

  # ########### Patch

  print '</td></tr><tr><td class="'.utils_get_alt_row_color($i).'">

<h3>Patch manager:</h3>
<br /><INPUT TYPE="CHECKBOX" NAME="form_can_use_patch" VALUE="1"'.( ($row_grp['can_use_patch']==1) ? ' checked="checked"' : '' ).'> can use patch manager.

';
  $i++;

  # ###########  Task

  print '</td></tr><tr><td class="'.utils_get_alt_row_color($i).'">

<h3>Task manager:</h3>
<br /><INPUT TYPE="CHECKBOX" NAME="form_can_use_task" VALUE="1"'.( ($row_grp['can_use_task']==1) ? ' checked="checked"' : '' ).'> can use task manager.

';
  $i++;

  # ###########  News

  print '</td></tr><tr><td class="'.utils_get_alt_row_color($i).'">

<h3>News:</h3>
<br /><INPUT TYPE="CHECKBOX" NAME="form_can_use_news" VALUE="1"'.( ($row_grp['can_use_news']==1) ? ' checked="checked"' : '' ).'> can use news.

';
  $i++;

  # ###########  Support

  print '</td></tr><tr><td class="'.utils_get_alt_row_color($i).'">

<h3>Support Request Manager:</h3>
<br /><INPUT TYPE="CHECKBOX" NAME="form_can_use_support" VALUE="1"'.(($row_grp['can_use_support']==1) ? ' checked="checked"' : '' ).'> can use support request tracker.

';
  $i++;

  # ########### Bugs

  print '</td></tr><tr><td class="'.utils_get_alt_row_color($i).'">

<h3>Bug Tracker:</h3>
<br /><INPUT TYPE="CHECKBOX" NAME="form_can_use_bug" VALUE="1"'.(($row_grp['can_use_bug']==1) ? ' checked="checked"' : '' ).'> can use bug tracker.';

  $HTML->box1_bottom();

print '
<p align="center">
<input type="submit" name="update" value="'.$update_button_text.'"> &nbsp;
<input type="submit" name="delete" value="'._("Delete this Group Type").'">';


  print '<br /><br />';

  # ####################################################################
  # PROJECTS MENU SETTINGS
  # ####################################################################

  $HTML->box1_top(_("Project Menu Settings"));
  print '<p>This form allows you to choose which menu entries are configurable by the projects administrators.</p>';
  $i = 1;

  function specific_checkbox ($val, $explanation, $increment=1)
    {
      # just a little fonction to clean that part of the code, no
      # interest to generalize it
      global $i, $row_grp;
      if ($increment)
	{ $i++; }
      print '</td></tr><tr><td class="'.utils_get_alt_row_color($i).'">';
      html_build_checkbox("form_is_menu_configurable_".$val, $row_grp["is_menu_configurable_".$val]);
      print '<font class="preinput">'.$explanation.'</font>';
    }

  specific_checkbox("homepage",
		    _("the homepage link can be modified"));

  specific_checkbox("extralink_documentation",
		    _("the documentation \"extra\" link can be modified"));

  specific_checkbox("download",
		    _("the download area link can be modified"));
  $row_grp["is_menu_configurable_download_dir"] = $row_grp["is_configurable_download_dir"];
  specific_checkbox("download_dir",
		    _("the download _directory_ can be modified -- beware, if the backend is running and creating download dir, it can be used maliciously. don't activate this feature unless you truly know what you're doing"));

  specific_checkbox("support",
		    _("the support link can be modified"));

  specific_checkbox("forum",
		    _("the forum link can be modified"));

  specific_checkbox("mail",
		    _("the mailing-list link can be modified"));

  specific_checkbox("cvs",
		    _("the cvs link can be modified"));
  specific_checkbox("cvs_viewcvs",
		    _("the viewcvs link can be modified"),0);
  specific_checkbox("cvs_viewcvs_homepage",
		    _("the viewcvs link for homepage code can be modified"),0);

  specific_checkbox("bugs",
		    _("the bugs tracker link can be modified"));

  specific_checkbox("task",
		    _("the task tracker link can be modified"));

  specific_checkbox("patch",
		    _("the patch tracker link can be modified"));

  print '</td></tr><tr><td class="'.utils_get_alt_row_color(1).'">';


  $HTML->box1_bottom();

  print '<p align="center"><input type="submit" name="update" value="'.$update_button_text.'"> &nbsp;
<input type="submit" name="delete" value="'._("Delete this Group Type").'">';

  print '<br /><br />';

  # ####################################################################
  # PROJECTS USERS SETTINGS
  # ####################################################################

  $HTML->box1_top(_("Project Default Member Permissions"));

  print '<p>This form allows you to define the default permissions for users added to a group of this type, unless this group defined its own configuration.</p>';

  $title_arr=array();
  $title_arr[]=_("Support Tracking");
  $title_arr[]=_("Bug Tracking");
  $title_arr[]=_("Task Tracking");
  $title_arr[]=_("Patch Tracking");
  $title_arr[]=_("News Manager");
  print html_build_list_table_top ($title_arr);

  html_select_permission_box("support", $row_grp['support_flags'], "type");
  html_select_permission_box("bugs", $row_grp['bugs_flags'], "type");
  html_select_permission_box("task", $row_grp['task_flags'], "type");
  html_select_permission_box("patch", $row_grp['patch_flags'], "type");
  html_select_permission_box("news", $row_grp['news_flags'], "type");

  print '  </tr>
</table>';

  $HTML->box1_bottom();

 print '<p align="center"><input type="submit" name="update" value="'.$update_button_text.'"> &nbsp;
<input type="submit" name="delete" value="'._("Delete this Group Type").'">';

  print '<br /><br />';

  $HTML->box1_top(_("Project Default Posting Restrictions"));

  print '<p>This form allows you to define the default posting restriction on this group trackers.</p>';

  $title_arr=array();
  $title_arr[]=_("Support Tracking");
  $title_arr[]=_("Bug Tracking");
  $title_arr[]=_("Task Tracking");
  $title_arr[]=_("Patch Tracking");
  $title_arr[]=_("News Manager");
  print html_build_list_table_top ($title_arr);

  html_select_restriction_box("support", $row_grp['support_rflags'], "type");
  html_select_restriction_box("bugs", $row_grp['bugs_rflags'], "type");
  html_select_restriction_box("task", $row_grp['task_rflags'], "type");
  html_select_restriction_box("patch", $row_grp['patch_rflags'], "type");
  html_select_restriction_box("news", $row_grp['news_rflags'], "type");
  
  print '  </tr>
</table>';

  $HTML->box1_bottom();

  print '<p align="center">
<input type="submit" name="update" value="'.$update_button_text.'"> &nbsp;
<input type="submit" name="delete" value="'._("Delete this Group Type").'"></p>
</form>';


}

site_admin_footer(array());

?>